/***************************************************************
 * Name:      dxutils.cpp
 * Author:    David Vachulka (archdvx@dxsolutions.org)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#include <wx/file.h>
#include <wx/stdpaths.h>
#include <wx/filename.h>
#include <wx/numformatter.h>
#include "dxutils.h"
#include "settings.h"
#include "model/dbmodel.h"

dxutils::dxutils()
{
}

dxutils &dxutils::instance()
{
    static dxutils idxutils;
    return idxutils;
}

wxString dxutils::enquotes(const wxString &text, const wxString &delim)
{
    wxString result = text;
    if(result.Contains(delim) || result.Contains("\""))
    {
        result.Replace("\"", "\"\"", true);
        result = wxString() << "\"" << result << "\"";
    }
    result.Replace("\t","    ", true);
    result.Replace("\n"," ", true);
    return result;
}

void dxutils::correctEmptyFileExt(const wxString &ext, wxString &fileName)
{
    wxFileName tempFileName(fileName);
    if(tempFileName.GetExt().IsEmpty())
        fileName << "." << ext;
}

int dxutils::numberOfChar(wxUniChar ch, const wxString& text)
{
    int result = 0;
    for(size_t i=0; i < text.Len(); i++)
    {
        if(text[i] == ch)
        {
            result++;
        }
    }
    return result;
}

bool dxutils::hasString(wxArrayString &strings, wxString value)
{
    for(size_t i=0; i<strings.GetCount(); i++)
    {
        if(strings[i] == value) return true;
    }
    return false;
}

bool dxutils::hasAmPm()
{
    tm tm;
    memset(&tm, 0, sizeof(struct tm));
    tm.tm_mday = 1;   // mday 0 is invalid
    tm.tm_year = 76;  // any valid year
    tm.tm_isdst = -1;
    wxChar buffer[64];
    if(wxStrftime(buffer, WXSIZEOF(buffer), wxT("%p"), &tm) > 0)
    {
        return true;
    }
    return false;
}
